@@ -1,8 +1,6 @@
 import json
 import numpy as np
 import ds_format as ds
-import datetime as dt
-import aquarius_time as aq
 
 READ_EXT = ['json']
 WRITE_EXT = ['json']
@@ -12,7 +10,7 @@ def read(filename, variables=None, sel=None, full=False, jd=False):
 		d = json.load(f)
 		for var in ds.vars(d):
 			data = ds.var(d, var)
-			if type(data) is list:
+			if isinstance(data, list):
 				ds.var(d, var, np.array(data))
 	return d
 
